from typing import Any, Union

from sanic import Sanic
from sanic import response
from jinja2 import Environment, PackageLoader, select_autoescape, Template


app = Sanic(__name__)

# Load the template environment with async support
template_env = Environment(
    loader=PackageLoader('iapp'),  # 所需文件
    autoescape=select_autoescape(),
    enable_async=True
)

# Load the template from file
template = template_env.get_template("example_template.html")
index_template = template_env.get_template("index.html")
meeting_template = template_env.get_template("meeting.html")
upload_template = template_env.get_template("upload.html")



@app.route('/')
async def test(request):
    input = request.args
    output = input.get('v', 'Hello World')

    rendered_template = await template.render_async(knights=output)
    return response.html(rendered_template)



@app.route('/index', ["GET", "POST"])
async def index(request):
    _ = await index_template.render_async(body="body")
    return response.html(_)


@app.route('/meeting', methods=["GET", "POST"])
async def meeting(request):
    """
    TODO: dic
    """
    _ = await meeting_template.render_async(body="body", dic={'body': 666})
    return response.html(_)

@app.route('/upload', methods=["GET", "POST"])
async def meeting(request):

    print(request.files)
    print(request.args)

    _ = await upload_template.render_async(result=6666666)
    return response.html(_)



app.run(host="0.0.0.0", port=2233, debug=True)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : downloda
# @Time         : 2019-08-30 13:32
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

import os
import yaml
import requests
from pathlib import Path
from itertools import chain
from .ModelPredictor import ModelPredictor

# models 加入环境变量
models = os.environ['--models']
os.sys.path.append(models)

# models home
fds = "http://cnbj1.fds.api.xiaomi.com/browser-algo-nanjing/models/"

# 下载配置文件
config_url = fds + "config.yml"
_ = requests.get(config_url, timeout=10).text
config = yaml.safe_load(_)
print(config)

# 新建models文件夹： /home/work
create_path = lambda path: Path(path).mkdir(parents=True, exist_ok=True)
create_path(models)

# 下载并加载
for file in chain(*config.items()):
    os.popen(f'wget {fds + file} -O {models}/{file}').read()

model2transformer = {}
for model_file, transformer_file in config.items():
    model_type = model_file.split('_')[0]
    print(f"{models}/{model_file}")
    predict = ModelPredictor().predictor(f"{models}/{model_file}", model_type)
    feature_transform = __import__(transformer_file[:-3]).feature_transform
    model2transformer[model_file] = predict, feature_transform

# Tricks:
# auto_reload 监控update.py 热更新：设置环境变量不奏效
# 可通过环境变量设置 全局变量



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : app
# @Time         : 2019-11-21 11:04
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

import os
import time
from flask import Flask

app = Flask(__name__)



os.system(f"echo {time.ctime()} >> ./log/test.log")


@app.route('/')
def index():
    return 'hello world!'

# if __name__ == '__main__':
#     # app.run()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : FlaskApp
# @Time         : 2019-11-26 13:19
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


from flask import Flask, request
from flask_restful import Api, Resource
from werkzeug.datastructures import ImmutableMultiDict

app = Flask(__name__)
api = Api(app)

class HelloWorld(Resource):
    def get(self):
        print(request.args)
        print(request.form)
        print(request.json)
        return 'get'

    def post(self):
        print(request.args)
        print(request.form)
        print(request.json)
        
        print(type(request.args))
        return 'post'


api.add_resource(HelloWorld, '/')

if __name__ == "__main__":
    app.run(debug=True)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : fromScheduler
# @Time         : 2019-09-02 14:34
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


from .scheduler import app

app.run()


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : make_scheduler
# @Time         : 2019-12-10 13:32
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

from apscheduler.schedulers.background import BackgroundScheduler


def task1():
    import logging
    import time
    logging.warning(f'Task1: {time.ctime()}')


def task2():
    import logging
    import time
    logging.warning(f'Task2: {time.ctime()}')


class Scheduler(object):

    def __init__(self):
        self.scheduler = BackgroundScheduler()

    def add_job(self, func, trigger=None, args=None, kwargs=None, id=None, name=None, **trigger_args):
        assert callable(func), "TODO: callable function"

        self.scheduler.add_job(func, 'interval', **trigger_args)

    def start(self):
        self.scheduler.start()


if __name__ == '__main__':
    scheduler = Scheduler()
    scheduler.add_job(task1, 'interval', seconds=3)
    scheduler.add_job(task2, 'interval', seconds=10)
    scheduler.start()

    while 1:
        pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : __init__.py
# @Time         : 2019-12-10 17:24
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


from loguru import logger

trace = logger.add('runtime_{time}.log', rotation="100 MB", retention='10 days')
logger.debug('this is a debug message')

if __name__ == '__main__':
    @logger.catch()
    def f():
        1/0
        return 1111

    print(f())


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-Python.
# @File         : plus
# @Time         : 2019-08-29 13:57
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


from japronto import Application


def hello(request):
    return request.Response(text='Hello world!')


app = Application()
app.router.add_route('/', hello)
app.run(debug=True, port=7766)